@@ -4,7 +4,4 @@ demal
 MAL (Meta Attack Language) to JSON decoding library and command-line tool.
 """
 
-__version__ = "1.2.0"
-__author__ = 'Victor Azzam'
-
-from .demal import MalParser
\ No newline at end of file
+from .demal import *
\ No newline at end of file
